################################################################################################
# Define differentially methylated regions
# Thresholds: adjusted P-value ≤ 0.05 & |log2(quotient of mean DNA methylation levels)| ≥ 0.5
################################################################################################

# Apply the thresholds on the diffMethTable generated by RnBeads

# PROMOTERS
awk -F "\t" '{if(NR>1 && $15 >= 0.5 && $24 <=0.05) {print $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $10 "\t" $14 "\t" $15 "\t" $25}}' diffMethTable_region_cmp7_promoters.Tumor_high_vs_Tumor_low.bed > PROMOTERS.hypermethyl.meanquotlog2_05_FDR_05.bed
awk -F "\t" '{if(NR>1 && $15 <= -0.5 && $24 <=0.05) {print $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $10 "\t" $14 "\t" $15 "\t" $25}}' diffMethTable_region_cmp7_promoters.Tumor_high_vs_Tumor_low.bed > PROMOTERS.hypomethyl.meanquotlog2_05_FDR_05.bed

# GENES
awk -F "\t" '{if(NR>1 && $15 > 0.5 && $24 <=0.05) {print $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $10 "\t" $14 "\t" $15 "\t" $25}}' diffMethTable_region_cmp7_genes.Tumor_high_vs_Tumor_low.bed > GENES.hypermethyl.meanquotlog2_05_FDR_05.bed
awk -F "\t" '{if(NR>1 && $15 <= -0.5 && $24 <=0.05) {print $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $10 "\t" $14 "\t" $15 "\t" $25}}' diffMethTable_region_cmp7_genes.Tumor_high_vs_Tumor_low.bed> GENES.hypomethyl.meanquotlog2_05_FDR_05.bed

# CPGs
awk -F "\t" '{if(NR>1 && $13 >= 0.5 && $22 <=0.05) {print $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $6 "\t" $12 "\t" $13 "\t" $22}}' diffMethTable_region_cmp7_cpgislands.Tumor_high_vs_Tumor_low.bed> CPGISLANDS.hypermethyl.meanquotlog2_05_FDR_05.bed
awk -F "\t" '{if(NR>1 && $13 <= -0.5 && $22 <=0.05) {print $1 "\t" $2 "\t" $3 "\t" $4 "\t" $5 "\t" $6 "\t" $12 "\t" $13 "\t" $22}}' diffMethTable_region_cmp7_cpgislands.Tumor_high_vs_Tumor_low.bed> CPGISLANDS.hypomethyl.meanquotlog2_05_FDR_05.bed




# Liftover the coordinates of significantly differentially methylated regions from mm10 to mm9

for i in *.bed
do
cut -f1-3 $i > ${i%.bed}.3col.bed
done


mkdir bed_mm10ToMm9
for i in *.3col.bed
do
echo $i

liftOver -minMatch=0.95 ${i} /home/himrichova/1_Projects/resources/liftover_over_chain/mm10ToMm9.over.chain bed_mm10ToMm9/${i%.bed}.mm10ToMm9.bed bed_mm10ToMm9/${i%.bed}.mm10ToMm9.log
done
